@@ -5,13 +5,12 @@
 package Tk::Multi::Canvas ;
 
 use strict;
-use Tk::Multi::Any;
 
 use vars qw(@ISA $printCmd $defaultPrintCmd $VERSION);
 
-@ISA = qw(Tk::Derived Tk::Frame Tk::Multi::Any);
+@ISA = qw(Tk::Derived Tk::Frame);
 
-$VERSION = sprintf "%d.%03d", q$Revision: 2.2 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%03d", q$Revision: 2.3 $ =~ /(\d+)\.(\d+)/;
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
